==> qtjambi-webenginecore-5.15.8-sources.jar: io/qt/webengine/core/QWebEngineRegisterProtocolHandlerRequest.java <==
package io.qt.webengine.core;


/**
 * <p>Enables accepting or rejecting requests from the registerProtocolHandler API</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html">QWebEngineRegisterProtocolHandlerRequest</a></p>
 */
public class QWebEngineRegisterProtocolHandlerRequest extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineRegisterProtocolHandlerRequest.class);
    
    
    public QWebEngineRegisterProtocolHandlerRequest(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineRegisterProtocolHandlerRequest instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#accept">QWebEngineRegisterProtocolHandlerRequest::accept()</a></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#operator-eq-eq">QWebEngineRegisterProtocolHandlerRequest::operator==(QWebEngineRegisterProtocolHandlerRequest)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.webengine.core.QWebEngineRegisterProtocolHandlerRequest that){
        return operator_equal_native_cref_QWebEngineRegisterProtocolHandlerRequest_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(that));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineRegisterProtocolHandlerRequest_constfct(long __this__nativeId, long that);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#origin-prop">QWebEngineRegisterProtocolHandlerRequest::origin()const</a></p>
     */
    @io.qt.QtPropertyReader(name="origin")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#reject">QWebEngineRegisterProtocolHandlerRequest::reject()</a></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#scheme-prop">QWebEngineRegisterProtocolHandlerRequest::scheme()const</a></p>
     */
    @io.qt.QtPropertyReader(name="scheme")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String scheme(){
        return scheme_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String scheme_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineRegisterProtocolHandlerRequest(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineRegisterProtocolHandlerRequest) {
            return operator_equal((io.qt.webengine.core.QWebEngineRegisterProtocolHandlerRequest) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QWebEngineRegisterProtocolHandlerRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineRegisterProtocolHandlerRequest clone_native(long __this_nativeId);
}

==> qtjambi-webenginecore-5.15.10-sources.jar: io/qt/webengine/core/QWebEngineRegisterProtocolHandlerRequest.java <==
package io.qt.webengine.core;


/**
 * <p>Enables accepting or rejecting requests from the registerProtocolHandler API</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html">QWebEngineRegisterProtocolHandlerRequest</a></p>
 */
public class QWebEngineRegisterProtocolHandlerRequest extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineRegisterProtocolHandlerRequest.class);
    
    
    public QWebEngineRegisterProtocolHandlerRequest(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineRegisterProtocolHandlerRequest instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#accept">QWebEngineRegisterProtocolHandlerRequest::accept()</a></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#operator-eq-eq">QWebEngineRegisterProtocolHandlerRequest::operator==(QWebEngineRegisterProtocolHandlerRequest)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.webengine.core.QWebEngineRegisterProtocolHandlerRequest that){
        return operator_equal_native_cref_QWebEngineRegisterProtocolHandlerRequest_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(that));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineRegisterProtocolHandlerRequest_constfct(long __this__nativeId, long that);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#origin-prop">QWebEngineRegisterProtocolHandlerRequest::origin()const</a></p>
     */
    @io.qt.QtPropertyReader(name="origin")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#reject">QWebEngineRegisterProtocolHandlerRequest::reject()</a></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineregisterprotocolhandlerrequest.html#scheme-prop">QWebEngineRegisterProtocolHandlerRequest::scheme()const</a></p>
     */
    @io.qt.QtPropertyReader(name="scheme")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String scheme(){
        return scheme_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String scheme_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineRegisterProtocolHandlerRequest(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineRegisterProtocolHandlerRequest) {
            return operator_equal((io.qt.webengine.core.QWebEngineRegisterProtocolHandlerRequest) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QWebEngineRegisterProtocolHandlerRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineRegisterProtocolHandlerRequest clone_native(long __this_nativeId);
}
